# Session

A Session object can be thought of as a collection of streams on which you may operate (publish or subscribe), or more simply as a "room". 
You can construct this object using [opentok.createSession(props)](opentok.md#createsessionprops). A [sessionId can be dynamically created](http://www.tokbox.com/opentok/docs/concepts/session_creation.html) by your backend web service.
This object is analogous to the [JS API Session](http://www.tokbox.com/opentok/docs/js/reference/Session.html) object.

<nav>
  <table>
    <tr>
      <th>Methods</th>
      <th>Properties</th>
      <th>Events</th>
    </tr>
    <tr>
      <td><a href="#connectapikey-token">connect(apiKey, token)</a></td>
      <td><a href="#sessionid">sessionId</a></td>
      <td><a href="#sessionconnected">sessionConnected</a></td>
    </tr>
    <tr>
      <td><a href="#disconnect">disconnect()</a></td>
      <td><a href="#streams">streams</a></td>
      <td><a href="#sessiondisconnected">sessionDisconnected</a></td>
    </tr>
    <tr>
      <td><a href="#publish_props_">publish(props)</a></td>
      <td><a href="#sessionconnectionstatus">sessionConnectionStatus</a></td>
      <td><a href="#sessionfailed">sessionFailed</a></td>
    </tr>
    <tr>
      <td><a href="#unpublish">unpublish()</a></td>
      <td><a href="#connectioncount">connectionCount</a></td>
      <td><a href="#streamcreated">streamCreated</a></td>
    </tr>
    <tr>
      <td><a href="#subscribestream-props">subscribe(stream, props)</a></td>
      <td><a href="#streamdestroyed">streamDestroyed</a></td>
    </tr>
  </table>
</nav>

## Methods

### connect(_apiKey_, _token_)

Connect to an OpenTok session. This must be done before you can do anything else with a session.

Parameters:
*  _apiKey_ (String) _required_ - OpenTok API Key. Get one [here](https://dashboard.tokbox.com/users/sign_in)
*  _token_ (String) _required_ - User Token. This is generated by a server-side SDK.

Returns: (void)

### disconnect()

Disconnect to an OpenTok session.

Returns: (void)

### publish(_props_)

Begin publishing video data from the device's camera to the Session. When the publisher begins streaming data, the Session dispatches
a ["streamCreated"](#streamcreated) event. You can compare the [connection.connectionId](connection.md#connectionid) property of the Session object with the stream.connection.connectionId
property of the "streamCreated" event object. If they match, the stream is published from your own connection.

Note that multiple publishers are not supported.

Parameters:
*  _props_ (Dictionary) _optional_:
   *  _name_ (String) _optional_ - A name for the stream being created in the Session. The name is readable to others connected to the Session. Defaults to device name.
   *  _publishAudio_ (Boolean) _optional_ - Whether or not the publisher sends audio. Defaults to true.
   *  _publishVideo_ (Boolean) _optional_ - Whether or not the publisher sends video. Defaults to true.

Returns: (Publisher)

### unpublish()

Stop publishing to the session.

Returns: (void)

### subscribe(_stream_, _props_)

Begin receiving video data from another device's camera who is publishing to the Session.

Parameters:
*  _stream_ (Stream) _required_ - A Stream object that refers to the video or audio data from a device.
*  _props_ (Dictionary) _optional_:
   *  _subscribeToAudio_ (Boolean) _optional_ - Whether or not to subscribe to the audio data. Defaults to true.
   *  _subscribeToVideo_ (Boolean) _optional_ - Whether or not to subscribe to the video data. Defaults to true.

Returns: (Subscriber)

## Properties

### sessionId

(String) The Session ID for this Session object. This is only writable before [session.connect(_apiKey_, _token_)](#connectapikey-token) is called.

### streams

(Array < Stream >) A collection of all the Streams currently in the Session. _Read Only_

### sessionConnectionStatus

(String) The state of the session. Possible values: "connected", "connecting", "disconnected", "failed". _Read Only_

### connectionCount

(Number) The number of connections in the Session. _Read Only_

## Events

### "sessionConnected"

This event is fired when the [session.connect(_apiKey_, _token_)](#connectapikey-token) call has resulted in a successful connection.

### "sessionDisconnected"

This event is fired when the [session.disconnect()](#disconnect) call has completed.

### "sessionFailed"

This event is fired when a session is disconnected for any reason other than a call to [session.disconnect()](#disconnect).

*  TODO: Describe how to read error description

### "streamCreated"

This event is fired when a new stream is available in the session. This happens when a connected device (this device or others) publishes.

Event Properties:
*   _stream_ (Stream) - The stream that was just created.

### "streamDestroyed"

This event is fired when a stream leaves a session. This can happen when a publishing device (this one or others) unpublishes or disconnects.

Event Properties:
*   _stream_ (Stream) - The stream that was just destroyed.

